---
title: 'A replication of: "Does High Public Debt Consistently Stifle Economic Growth?
  A Critique of Reinhart and Rogof"'
author: "Thomas de Graaff"
date: "Friday, August 22, 2014"
output: pdf_document
bibliography: bibliography.bib
abstract: |
  We replicate Reinhart and Rogoff (2010a and 2010b) and find that coding errors,
  selective exclusion of available data, and unconventional weighting of summary statistics
  lead to serious errors that inaccurately represent the relationship between public debt
  and GDP growth among 20 advanced economies in the post-war period. Our finding is
  that when properly calculated, the average real GDP growth rate for countries carrying
  a public-debt-to-GDP ratio of over 90 percent is actually 2.2 percent, not ???0.1 percent
  as published in Reinhart and Rogoff. That is, contrary to RR, average GDP growth
  at public debt/GDP ratios over 90 percent is not dramatically different than when
  debt/GDP ratios are lower.
  We also show how the relationship between public debt and GDP growth varies
  significantly by time period and country. Overall, the evidence we review contradicts
  Reinhart and Rogoff's claim to have identified an important stylized fact, that public
  debt loads greater than 90 percent of GDP consistently reduce GDP growth
---

# Introduction


In "Growth in Time of Debt" Reinhart and Rogoff (@reinhart2010growtha and @reinhart2010growthb; from here on RR) propose
a set of "stylized facts" concerning the relationship between public debt and GDP growth.
RR's "main result is that whereas the link between growth and debt seems relatively weak
at 'normal' debt levels, median growth rates for countries with public debt over roughly 90
percent of GDP are about one percent lower than otherwise; (mean) growth rates are several
percent lower" (@reinhart2010growtha, p. 573).

To build the case for a stylized fact, RR stresses the relevance of the relationship to
a range of times and places and the robustness of the finding to modest adjustments of
the econometric methods and categorizations. The RR methods are non-parametric and
appealingly straightforward. RR organizes country-years in four groups by public debt/GDP
ratios, 0--30 percent, 30--60 percent, 60--90 percent, and greater than 90 percent. They then
compare average real GDP growth rates across the debt/GDP groupings. The straightforward
non-parametric method highlights a nonlinear relationship, with effects appearing at levels
of public debt around 90 percent of GDP. We present RR's key results on mean real GDP
growth from Figure 2 of @reinhart2010growtha and Appendix Table 1 of @reinhart2010growthb in Table 1.



Table: Real GDP Growth as the Level of Public Debt Varies 20 advanced economies, 1946--2009

-------------------------------------------------------------------------
Ratio of public debt       below       30 to 60   60 to 90     90 percent 
to gdp                     30 percent  percent    percent      and above
---------------------      ----------- ---------  ---------    ----------
Average real grp           4.1         2.8        2.8          -0.1 
growth
-------------------------------------------------------------------------

Figure 2 in @reinhart2010growtha and the first line of Appendix Table 1 in @reinhart2010growthb in fact do not
match perfectly, but they do deliver a consistent message about growth in time of debt: real
GDP growth is relatively stable around 3 to 4 percent until the ratio of public debt to GDP
reaches 90 percent. At that point and beyond, average GDP growth drops sharply to zero or
slightly negative.

A necessary condition for a stylized fact is accuracy. We replicate RR and finnd that
coding errors, selective exclusion of available data, and unconventional weighting of summary statistics lead to serious errors that inaccurately represent the relationship between public debt and growth among these 20 advanced economies in the post-war period. Our most basic finding is that when properly calculated, the average real GDP growth rate for countries
carrying a public debt-to-GDP ratio of over 90 percent is actually 2.2 percent, not -0.1
percent as RR claims. That is, contrary to RR, average GDP growth at public debt/GDP
ratios over 90 percent is not dramatically different than when public debt/GDP ratios are
lower.

We additionally refute the RR evidence for an "historical boundary" around public
debt/GDP of 90 percent, above which growth is substantively and non-linearly reduced. In
fact, there is a major non-linearity in the relationship between public debt and GDP growth,
but that non-linearity is between the lowest two public debt/GDP categories, 0--30 percent
and 30--60 percent, a range that is not relevant to current policy debate.

For the purposes of this discussion, we follow RR in assuming that causation runs from
public debt to GDP growth. RR concludes, "At the very minimum, this would suggest that
traditional debt management issues should be at the forefront of public policy concerns" [@reinhart2010growtha, p. 578]. In other work (see, for example, @reinhart2011decade), Reinhart and
Rogoff acknowledge the potential for reverse causality, i.e., that weak economic growth may
increase debt by reducing tax revenue and increasing public expenditures. [@reinhart2010growtha;@reinhart2010growthb] however, make clear that the implied direction of causation runs from public debt to GDP growth.

## Publication, Citations, Public Impact, and Policy Relevance

According to Reinhart's and Rogoff's website[^1] the findings reported in the two 2010 papers
formed the basis for testimony before the Senate Budget Committee (Reinhart, February 9,
2010) and a Financial Times opinion piece "Why We Should Expect Low Growth amid Debt"

[^1]: http://www.reinhartandrogoff.com/related-research/growth-in-a-time-of-debt-featured-in
(visited 7 April 2013).

The key tables and figures have been reprinted in additional Reinhart and Rogoff publications and presentations of Centre for Economic Policy Research and the Peter G. Peterson Institute for International Economics. A Google Scholar
search for the publication excluding pieces by the authors themselves finds more than 500
results.[^2] 

[^2]: A search on [Reinhart Rogoff "Growth in a Time of Debt" -author:rogoff -author:reinhart]
yielded 538 Google Scholar results on 7 April 2013).

The key findings have also been widely cited in popular media. Reinhart's and Rogoff's
website lists 76 high-profile features, including *The Economist, Wall Street Journal, New
York Times, Washington Post*, Fox News, National Public Radio, and MSNBC, as well as
many international publications and broadcasts.

Furthermore, [@reinhart2010growtha] is the only evidence cited in the "Paul Ryan Budget" on the
consequences of high public debt for economic growth. Representative Ryan's "Path to Prosperity" reports

> A well-known study completed by economists Ken Rogoff and Carmen Reinhart
> confirms this common-sense conclusion. The study found conclusive empirical
> evidence that gross debt (meaning all debt that a government owes, including
> debt held in government trust funds) exceeding 90 percent of the economy has a
> significant negative eect on economic growth. [@house2012path, p. 78]

RR have clearly exerted a major in uence in recent years on public policy debates over
the management of government debt and fiscal policy more broadly. Their findings have
provided significant support for the austerity agenda that has been ascendant in Europe and
the United States since 2010.

# Replication



